/***************************************************************************
 *   Copyright (C) 2004-2005 by Andrew Krause                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef ENVIRONMENT_H
#define ENVIRONMENT_H

#include "utils.h"

#include <gtkmm/adjustment.h>
#include <gtkmm/button.h>
#include <gtkmm/buttonbox.h>
#include <gtkmm/checkbutton.h>
#include <gtkmm/colorbutton.h>
#include <gtkmm/dialog.h>
#include <gtkmm/entry.h>
#include <gtkmm/fixed.h>
#include <gtkmm/fontbutton.h>
#include <gtkmm/fontselection.h>
#include <gtkmm/image.h>
#include <gtkmm/label.h>
#include <gtkmm/notebook.h>
#include <gtkmm/spinbutton.h>
#include <gtkmm/table.h>

// Environment Dialog class
class EnvironmentDialog : public Gtk::Dialog
{
public:
  EnvironmentDialog (EnvironmentSettings*);
  ~EnvironmentDialog();

  void initialize_objects();  
  int get_asave_minutes();
  int get_tab_size();
  int get_undo();
  bool get_load_on_launch();
  bool get_replace_tabs();
  bool get_auto_indent();
  Glib::ustring get_font_size();
  Glib::ustring get_font_face();
  Glib::ustring get_error_color();
  Glib::ustring get_warning_color();

private:
  Gtk::Notebook *notebook;
  Gtk::Button *cancel, *ok;
  Gtk::Label *label_tabstops, *label_tabwidth, *label_filemanagement, *label_autosave, 
             *label_minutes, *label_editor, *label_font, *label_editor_font,
             *label_compiler, *label_error, *label_fonts, *label_vars, *label_actions, 
             *label_warning, *label_autoindent, *label_undo, *label_limitto;
  Gtk::Adjustment *tab_size_adj, *asave_minutes_adj, *undo_adj;
  Gtk::SpinButton *tab_size, *asave_minutes, *undo_actions;
  Gtk::CheckButton *replace_tabs, *load_on_launch, *autoindent;
  Gtk::HBox *hbox_tabsize, *hbox_autosave, *hbox_font, *hbox_undo;
  Gtk::VBox *vbox_editor, *vbox_font;
  Gtk::Fixed *fixed_tabs, *fixed_loadlaunch, *fixed_autoindent;
  Gtk::ColorButton *error, *warning;
  Gtk::FontButton *fontbutton;
  Gtk::Table *table_ew_color;
  Glib::ustring fontname;
};

#endif
