/***************************************************************************
 *   Copyright (C) 2005 by Andrew Krause                                   *
 *   Based on gtksourceviewmm by Rob Page                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <gtk/gtktextbuffer.h>

#include <gtksourceview/gtksourcebuffer.h>
#include <gtksourceview/gtksourcelanguagesmanager.h>
#include "sourceview/sourcebuffer.h"
#include "sourceview/private/sourcebuffer_p.h"

namespace Glib
{
  Gtk::SourceBuffer* wrap(GtkSourceBuffer* object, bool take_copy)
  { return dynamic_cast<Gtk::SourceBuffer*> (Glib::wrap_auto ((GObject*)(object), take_copy));
  }
}

namespace Gtk
{
  const Glib::Class& SourceBuffer_Class::init()
  {
    if(!gtype_)   
    {
      class_init_func_ = &SourceBuffer_Class::class_init_function;
      register_derived_type(gtk_source_buffer_get_type());
    }

    return *this;
  }

  void SourceBuffer_Class::class_init_function(void* g_class, void* class_data)
  {
    BaseClassType *const klass = static_cast<BaseClassType*>(g_class);
    CppClassParent::class_init_function(klass, class_data);
  }

  Glib::ObjectBase* SourceBuffer_Class::wrap_new(GObject* o)
  { return new SourceBuffer((GtkSourceBuffer*)(o));
  }

  SourceBuffer::SourceBuffer(const Glib::ConstructParams& construct_params)
              : Gtk::TextBuffer(construct_params)
  {
  }

  SourceBuffer::SourceBuffer(GtkSourceBuffer* castitem)
              : Gtk::TextBuffer((GtkTextBuffer*)(castitem))
  {
  }

  SourceBuffer::~SourceBuffer()
  {
  }

  SourceBuffer::CppClassType SourceBuffer::sourcebuffer_class_;

  GType SourceBuffer::get_type()
  { return sourcebuffer_class_.init().get_type();
  }

  GType SourceBuffer::get_base_type()
  { return gtk_source_buffer_get_type();
  }


  SourceBuffer::SourceBuffer()
              : Glib::ObjectBase(0), 
                Gtk::TextBuffer(Glib::ConstructParams(sourcebuffer_class_.init()))
  {
    GtkSourceLanguagesManager* lm = gtk_source_languages_manager_new();
    g_object_ref(lm);
    g_object_set_data_full (G_OBJECT (gobj()), "languages-manager",
                            lm, (GDestroyNotify) g_object_unref);
  }

  Glib::RefPtr <Gtk::SourceLanguagesManager> SourceBuffer::get_languages_manager()
  {
    Glib::RefPtr <Gtk::SourceLanguagesManager> retval = Glib::wrap((GtkSourceLanguagesManager*)(get_data ("languages-manager")));
    
    if(retval)
      retval->reference(); //The function does not do a ref for us.
    return retval;
  }

  void SourceBuffer::set_check_brackets (bool check)
  { gtk_source_buffer_set_check_brackets(gobj(), check);
  }

  bool SourceBuffer::get_check_brackets ()
  { return gtk_source_buffer_get_check_brackets(gobj());
  }

  void SourceBuffer::set_bracket_match_style(GtkSourceTagStyle *style)
  { gtk_source_buffer_set_bracket_match_style(gobj(), style);
  }

  void SourceBuffer::set_highlight (bool highlight)
  { gtk_source_buffer_set_highlight(gobj(), highlight);
  }

  bool SourceBuffer::get_highlight ()
  { return gtk_source_buffer_get_highlight(gobj());
  }

  void SourceBuffer::set_max_undo_levels(int max_undo_levels)
  { gtk_source_buffer_set_max_undo_levels(gobj(), max_undo_levels);
  }

  int SourceBuffer::get_max_undo_levels()
  { return gtk_source_buffer_get_max_undo_levels(gobj());
  }

  void SourceBuffer::set_language (Gtk::SourceLanguage* language)
  { gtk_source_buffer_set_language(gobj(), language->gobj());
  }

  GtkSourceLanguage* SourceBuffer::get_language()
  { return gtk_source_buffer_get_language(gobj());
  }

  void SourceBuffer::set_escape_char (gunichar escape_char)
  { gtk_source_buffer_set_escape_char(gobj(),escape_char);
  }
  
  gunichar SourceBuffer::get_escape_char ()
  { return gtk_source_buffer_get_escape_char(gobj());
  }

  bool SourceBuffer::can_undo()
  { return gtk_source_buffer_can_undo(gobj());
  }

  bool SourceBuffer::can_redo()
  { return gtk_source_buffer_can_redo(gobj());
  }

  void SourceBuffer::undo()
  { gtk_source_buffer_undo(gobj());
  }
  
  void SourceBuffer::redo()
  { gtk_source_buffer_redo(gobj());
  }

  void SourceBuffer::begin_not_undoable_action()
  { gtk_source_buffer_begin_not_undoable_action(gobj());
  }

  void SourceBuffer::end_not_undoable_action()
  { gtk_source_buffer_end_not_undoable_action(gobj());
  }
}
